@@ -1,3 +1,3 @@
 __author__ = 'Jonathan Sumrall'
 
-import xes
\ No newline at end of file
+from .xes import *
\ No newline at end of file
